@@ -7,16 +7,19 @@ import sys
 from matplotlib.figure import Figure
 import matplotlib.colors as colors
 import matplotlib.pyplot as plt
-from mpl_toolkits.mplot3d import Axes3D
 import pathlib
 import warnings
 from decimal import Decimal
 from motus import funciones_auxiliares as fa
-from motus import regiones_preferidas as rp
-from motus.fisica_estadistica import histogramas as m_hist, analisis_regresion_lineal as arl
-from motus.fisica_estadistica import entropia_divergencia as m_ed
+from motus.fisica_estadistica import histogramas as m_hist, velocidad_aceleracion as m_vel
+from motus.regresion_lineal import analisis_regresion_lineal as m_arl
+from motus.entropia_divergencia import entropia_divergencia as m_ed
+from motus.rutas_distancias import distancias as m_dist, rutas_vectoriales as m_rv
+from motus.graficador import cilindros as m_ci
+from motus.regiones_cuadriculadas import regiones_cuadriculadas as m_reg_cuad,\
+    regiones_preferidas as m_reg_pref, matrices_recurrencia as m_recurr
 import motus.graficador.config_graficas as m_cg
-from motus.graficador import cilindros
+
 
 warnings.filterwarnings("error")
 
@@ -27,7 +30,7 @@ class Experimento:
 
     def __init__(self, nombre_archivo, dimension_caja=[100, 100], cantidad_filas=10,
                  cantidad_columnas=10, procesar_tiempo_archivo_irregular=False,
-                 puntos_importantes=None, genera_matriz_recurrencia=False):
+                 puntos_importantes=None):
         self.nombre_archivo = nombre_archivo
         print("NOMBRE_ARCHIVO:", self.nombre_archivo, "\n TIPO_ARCHIVO:", type(self.nombre_archivo))
         self.dimension_caja = dimension_caja
@@ -41,8 +44,6 @@ class Experimento:
         self.entropias = dict()
         self.histogramas = dict()
 
-        self.config_graficas = m_cg.ConfigGrafica()
-
         nombre_recortado = pathlib.Path(self.nombre_archivo)
         try:
             dataframe_a_recortar = pd.DataFrame(pd.read_csv(self.nombre_archivo,
@@ -139,6 +140,11 @@ class Experimento:
 
         self.posiciones_x = arreglo_posicion_x
         self.posiciones_y = arreglo_posicion_y
+
+        self.config_graficas = m_cg.ConfigGrafica()
+        self.rutas_vectoriales = m_rv.InformacionRutasVectoriales(posiciones_eje_x=self.posiciones_x,
+                                                                  posiciones_eje_y=self.posiciones_y)
+
         self.tiempo = arreglo_tiempo
         self.samples = arreglo_samples
 
@@ -189,20 +195,17 @@ class Experimento:
         self.aceleracion_maxima = None
 
         self.arreglo_region_cuadriculada = None
-
-        self.matriz_recurrencia_objeto_1 = None
-        self.matriz_recurrencia_objeto_2 = None
-        self.matriz_recurrencia_objeto_3 = None
-        self.matriz_recurrencia_objeto_4 = None
-
+        self.lista_matrices_recurrencia_regiones_importantes = []
+        self.matriz_recurrencia_region_cuadriculada = None
         self.matriz_recurrencia_combinada = None
 
-        self.matriz_recurrencia_region_cuadriculada = None
         self.matriz_cuadriculada = None
         self.matriz_cuadriculada_regiones_preferidas = None
         self.matriz_cuadriculada_solo_regiones_preferidas = None
         self.matriz_cuadriculada_solo_regiones_no_preferidas = None
 
+        self.regiones_preferidas = None
+        self.regiones_no_preferidas = None
         self.visitas_regiones_preferidas = None
         self.visitas_regiones_no_preferidas = None
 
@@ -221,21 +224,6 @@ class Experimento:
             raise Exception('Hay un dato en el eje Y que es mayor que la dimensión de la caja. Valor: ',
                             self.posiciones_y.max())
 
-        self.realiza_procesamiento_MOTUS()
-
-        """
-        self.reduce_elementos_sesion_con_modulo(tamanio=tamanio_de_subsucesiones,
-                                                epsilon=epsilon,
-                                                subsucesiones_iniciales=subsucesiones_iniciales,
-                                                subsucesiones_aleatorias=subsucesiones_aleatorias)
-        """
-
-    def realiza_procesamiento_MOTUS(self):
-        self.calcula_distancias()
-        self.calcula_velocidades()
-        self.calcula_velocidades_promediadas()
-        self.calcula_regiones_cuadriculadas()
-
     def verifica_intervalo_tiempo(self):
         arreglo_tiempo = self.tiempo
         valor = True
@@ -262,30 +250,11 @@ class Experimento:
         self.tiempo = nuevos_tiempos
 
     def calcula_distancias(self):
-        # Este método calcula las distancias dependiendo del tipo de experimento definido en el constructor, además de
-        # obtener las distancias mínimas y la palanca asociada a la distancia.
 
         print("Cálculo de distancias...")
 
-        posiciones_x = self.posiciones_x.copy()
-        posiciones_y = self.posiciones_y.copy()
-
-        objeto_1_x = self.objeto_relevante_1[0]
-        objeto_1_y = self.objeto_relevante_1[1]
-
-        objeto_2_x = self.objeto_relevante_2[0]
-        objeto_2_y = self.objeto_relevante_2[1]
-
-        objeto_3_x = self.objeto_relevante_3[0]
-        objeto_3_y = self.objeto_relevante_3[1]
-
-        objeto_4_x = self.objeto_relevante_4[0]
-        objeto_4_y = self.objeto_relevante_4[1]
-
-        self.dist_objeto_1 = ((objeto_1_x - posiciones_x) ** 2 + (objeto_1_y - posiciones_y) ** 2) ** 0.5
-        self.dist_objeto_2 = ((objeto_2_x - posiciones_x) ** 2 + (objeto_2_y - posiciones_y) ** 2) ** 0.5
-        self.dist_objeto_3 = ((objeto_3_x - posiciones_x) ** 2 + (objeto_3_y - posiciones_y) ** 2) ** 0.5
-        self.dist_objeto_4 = ((objeto_4_x - posiciones_x) ** 2 + (objeto_4_y - posiciones_y) ** 2) ** 0.5
+        self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4 =  \
+            m_dist.calcula_distancias_a_objetos(self.posiciones_x, self.posiciones_y, self.lista_objetos_relevantes)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
                                            categoria="dist_objeto_1",
@@ -305,21 +274,10 @@ class Experimento:
 
         print("Distancias calculadas.")
 
-        self.distancia_minima_objetos_2_3_4 = np.minimum(self.dist_objeto_2,
-                                                         np.minimum(self.dist_objeto_3, self.dist_objeto_4))
-        self.distancia_minima_todos_objetos = np.minimum(self.dist_objeto_1, np.minimum(self.dist_objeto_2,
-                                                                                        np.minimum(self.dist_objeto_3,
-                                                                                                   self.dist_objeto_4)))
+        lista_dist_objetos = [self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4]
 
-        longitud_distancias = len(posiciones_x)
-
-        posiciones_x = posiciones_x.fillna(0)
-        posiciones_y = posiciones_y.fillna(0)
-
-        for i in range(1, longitud_distancias):
-            self.distancia_total_recorrida = self.distancia_total_recorrida + \
-                                             ((posiciones_x.iloc[i] - posiciones_x.iloc[i - 1]) ** 2 +
-                                              (posiciones_y.iloc[i] - posiciones_y.iloc[i - 1]) ** 2) ** (1 / 2)
+        self.distancia_minima_objetos_2_3_4, self.distancia_minima_todos_objetos, self.distancia_total_recorrida = \
+            m_dist.resultados_distancias(self.posiciones_x, self.posiciones_y, lista_dist_objetos)
 
         print("Distancia total calculada")
 
@@ -334,50 +292,25 @@ class Experimento:
         elif objeto is 4:
             arreglo_elegido = self.dist_objeto_4.tolist()
         self.distancia_a_objeto_promediado = \
-            fa.obtener_arreglo_con_valores_promediados_para_distancia_a_objeto(arreglo_elegido, intervalo)
+            m_dist.obtener_arreglo_con_valores_promediados_para_distancia_a_objeto(arreglo_elegido, intervalo)
 
     def calcula_velocidades(self):
 
-        print("Calculando la velocidad y aceleración del ratón...")
-        # valor_tiempo = self.valor_intervalos_tiempo
-
-        tiempos = self.tiempo
-
-        posiciones_x = self.posiciones_x
-        posiciones_y = self.posiciones_y
-
-        longitud_movimientos = len(posiciones_x)
-
-        lista_velocidad = np.zeros(longitud_movimientos)
-        for i in range(1, longitud_movimientos):
-
-            valor_tiempo = tiempos[i] - tiempos[i - 1]
-
-            if np.isnan(posiciones_x.iloc[i - 1]):
-                lista_velocidad[i - 1] == 0
-            elif np.isnan(posiciones_x.iloc[i]):
-                lista_velocidad[i - 1] == 0
-            else:
-                lista_velocidad[i - 1] = (((posiciones_x.iloc[i] - posiciones_x.iloc[i - 1]) ** 2 + (
-                        posiciones_y.iloc[i] - posiciones_y.iloc[i - 1]) ** 2) ** 0.5) / valor_tiempo
-        self.serie_velocidad = pd.Series(lista_velocidad)
-        self.velocidad_maxima = round(self.serie_velocidad.max(), 3)
+        self.serie_velocidad = m_vel.calcula_serie_velocidad(self.tiempo,
+                                                             self.posiciones_x,
+                                                             self.posiciones_y)
+        self.velocidad_maxima = round(round(self.serie_velocidad.max(), 3))
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
                                            categoria="velocidad",
                                            serie=self.serie_velocidad)
+
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="histograma_velocidad",
                                        datos=self.histogramas["velocidad"])
 
-        longitud_velocidad = len(lista_velocidad)
-        lista_aceleracion = np.zeros(longitud_velocidad)
-        for i in range(1, longitud_velocidad):
-            valor_tiempo = tiempos[i] - tiempos[i - 1]
-            lista_aceleracion[i - 1] = (self.serie_velocidad.iloc[i] - self.serie_velocidad.iloc[i - 1]) / valor_tiempo
-        self.serie_aceleracion = pd.Series(lista_aceleracion)
-        self.aceleracion_maxima = round(self.serie_aceleracion.max(), 3)
-        print("Velocidad y aceleración del ratón calculdadas.")
+        self.serie_aceleracion = m_vel.calcula_serie_aceleracion(arreglo_tiempo=self.tiempo,
+                                                                 serie_velocidad=self.serie_velocidad)
 
         m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
                                            categoria="aceleracion",
@@ -387,91 +320,38 @@ class Experimento:
                                        categoria="histograma_aceleracion",
                                        datos=self.histogramas["aceleracion"])
 
-    def calcula_velocidades_promediadas(self):
-        longitud_serie_velocidad = len(self.serie_velocidad)
-        longitud_serie_aceleracion = len(self.serie_aceleracion)
-        if longitud_serie_velocidad % 5 > 0:
-            x = 1
-        else:
-            x = 0
-        longitud_serie_velocidad_promedio = int(longitud_serie_velocidad / 5 + x)
-        lista_velocidad_promediada = np.zeros(longitud_serie_velocidad_promedio)
-        for i in range(0, longitud_serie_velocidad_promedio - 1):
-            for j in range(5):
-                lista_velocidad_promediada[i] = lista_velocidad_promediada[i] + self.serie_velocidad.iloc[5 * i + j]
-            lista_velocidad_promediada[i] = lista_velocidad_promediada[i] / 5
-        for j in range(len(self.serie_velocidad) % 5):
-            lista_velocidad_promediada[longitud_serie_velocidad_promedio - 1] = \
-                self.serie_velocidad.iloc[5 * (longitud_serie_velocidad_promedio - 1) + j]
-        self.serie_velocidad_promediada = pd.Series(lista_velocidad_promediada)
-        if longitud_serie_aceleracion % 5 > 0:
-            x = 1
-        else:
-            x = 0
-        longitud_serie_aceleracion_promedio = int(longitud_serie_aceleracion / 5 + x)
-        lista_aceleracion_promediada = np.zeros(longitud_serie_aceleracion_promedio)
-        for i in range(0, longitud_serie_aceleracion_promedio - 1):
-            # print(i)
-            for j in range(5):
-                lista_aceleracion_promediada[i] = lista_aceleracion_promediada[i] + self.serie_aceleracion.iloc[
-                    5 * i + j]
-            lista_aceleracion_promediada[i] = lista_aceleracion_promediada[i] / 5
-            # print (longVelProm-1)
-        for j in range(longitud_serie_aceleracion % 5):
-            lista_aceleracion_promediada[longitud_serie_aceleracion_promedio - 1] = \
-                self.serie_aceleracion.iloc[5 * (longitud_serie_aceleracion_promedio - 1) + j]
-        self.serie_aceleracion_promediada = pd.Series(lista_aceleracion_promediada)
+    def calcula_velocidades_promediadas(self, cantidad_datos_promedio):
+
+        self.serie_velocidad_promediada = m_vel.obtener_arreglo_promediado(self.serie_velocidad,
+                                                                           cantidad_datos_promedio)
+
+        m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
+                                           categoria="velocidad_promediada",
+                                           serie=self.serie_velocidad)
+
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="histograma_velocidad_promediada",
+                                       datos=self.histogramas["velocidad_promediada"])
+
+        self.serie_aceleracion_promediada = m_vel.obtener_arreglo_promediado(self.serie_aceleracion,
+                                                                             cantidad_datos_promedio)
+        m_hist.agrega_categoria_histograma(diccionario_histograma=self.histogramas,
+                                           categoria="aceleracion_promediada",
+                                           serie=self.serie_velocidad)
+
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="histograma_aceleracion_promediada",
+                                       datos=self.histogramas["aceleracion_promediada"])
 
     def calcula_regiones_cuadriculadas(self):
 
-        print("Calculando regiones en la caja...")
-
-        posiciones_x = self.posiciones_x
-        posiciones_y = self.posiciones_y
-
-        cantidad_tiempos = len(self.tiempo)
-        cantidad_filas = self.cantidad_filas
-        cantidad_columnas = self.cantidad_columnas
-
-        self.matriz_cuadriculada = np.zeros((cantidad_filas, cantidad_columnas))
-
-        tamanio_horizontal = self.dimension_caja[0] / cantidad_columnas
-        tamanio_vertical = self.dimension_caja[1] / cantidad_filas
-
-        print("Tamaño de los cuadros: ", tamanio_horizontal, "x", tamanio_vertical)
-
-        self.arreglo_region_cuadriculada = np.zeros(cantidad_tiempos)
-
-        arreglo_region_cuadriculada = self.arreglo_region_cuadriculada
-
-        for k in range(cantidad_tiempos):
-            # print("Posicion de k:", k)
-
-            if not (np.isnan(posiciones_x.iloc[k])) or not (np.isnan(posiciones_y.iloc[k])):
-
-                posicion_x = posiciones_x.iloc[k]
-                posicion_y = posiciones_y.iloc[k]
-                # print("Indice:", k)
-                if posicion_x == self.dimension_caja[0]:
-                    # print(cantidad_columnas)
-                    j = cantidad_columnas - 1
-                    # print("Entro en opción 1-x")
-                else:
-                    # print("Entro en opcion 2-x")
-                    j = int(posiciones_x.iloc[k] // tamanio_horizontal)
-                if posicion_y == self.dimension_caja[1]:
-                    # print(cantidad_filas)
-                    i = cantidad_filas - 1
-                    # print("Entro en opcion 1-y")
-                else:
-                    i = int(posiciones_y.iloc[k] // tamanio_vertical)
-                    # print("Entro en opcion 2-y")
-                # print("i: ", i)
-                # print("j: ", j)
-                self.matriz_cuadriculada[i][j] = self.matriz_cuadriculada[i][j] + 1
-                arreglo_region_cuadriculada[k] = cantidad_columnas * i + j
-
-            self.matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
+        self.arreglo_region_cuadriculada, self.matriz_cuadriculada = \
+            m_reg_cuad.calcula_regiones_preferidas(tiempos=self.tiempo,
+                                                   serie_posiciones_x=self.posiciones_x,
+                                                   serie_posiciones_y=self.posiciones_y,
+                                                   cantidad_filas=self.cantidad_filas,
+                                                   cantidad_columnas=self.cantidad_columnas,
+                                                   dimension_caja=self.dimension_caja)
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones",
@@ -480,59 +360,33 @@ class Experimento:
         print(self.matriz_cuadriculada)
 
     def calcula_matrices_de_recurrencia(self):
-
-        self.obtener_indice_regiones_objeto()
-
-        cantidad_tiempos = len(self.tiempo)
-
-        arreglo_region_cuadriculada = self.arreglo_region_cuadriculada
-
-        longitud_matriz_recurrencia = len(arreglo_region_cuadriculada)
-
         self.matriz_recurrencia_region_cuadriculada = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+            m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada)
 
-        self.matriz_recurrencia_objeto_1 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-        self.matriz_recurrencia_objeto_2 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-        self.matriz_recurrencia_objeto_3 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
-        self.matriz_recurrencia_objeto_4 = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+        lista_indices = [self.indice_region_objeto_1,
+                         self.indice_region_objeto_2,
+                         self.indice_region_objeto_3,
+                         self.indice_region_objeto_4]
+
+        self.lista_matrices_recurrencia_regiones_importantes = []
+
+        for indice in lista_indices:
+            matriz = m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada,
+                                                              region_importante=indice)
+            self.lista_matrices_recurrencia_regiones_importantes.append(matriz)
 
         self.matriz_recurrencia_combinada = \
-            np.zeros((longitud_matriz_recurrencia, longitud_matriz_recurrencia))
+            m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada,
+                                                     region_importante=lista_indices)
 
-        for i in range(cantidad_tiempos):
-            valor = arreglo_region_cuadriculada[i]
-            for j in range(cantidad_tiempos):
-                if valor == arreglo_region_cuadriculada[j]:
-                    self.matriz_recurrencia_region_cuadriculada[i][j] = 1
-                    if valor == self.indice_region_objeto_1:
-                        print("Entro en 1")
-                        self.matriz_recurrencia_objeto_1[i][j] = 1
-                        self.matriz_recurrencia_combinada[i][j] = 1
-                    if valor == self.indice_region_objeto_2:
-                        print("Entro en 2")
-                        self.matriz_recurrencia_objeto_2[i][j] = 1
-                        self.matriz_recurrencia_combinada[i][j] = 2
-                    if valor == self.indice_region_objeto_3:
-                        print("Entro en 3")
-                        self.matriz_recurrencia_objeto_3[i][j] = 1
-                        self.matriz_recurrencia_combinada[i][j] = 3
-                    if valor == self.indice_region_objeto_4:
-                        print("Entro en 4")
-                        self.matriz_recurrencia_objeto_4[i][j] = 1
-                        self.matriz_recurrencia_combinada[i][j] = 4
-
-    def calcula_matrices_regiones_preferidas(self):
+    def calcula_matrices_solo_regiones_preferidas(self):
 
         print("Se inicia el procesamiento de las matrices con regiones preferidas")
         matriz_cuadriculada = np.flipud(self.matriz_cuadriculada)
+        print("Se toma matriz cuadriculada", matriz_cuadriculada)
 
         self.matriz_cuadriculada_solo_regiones_preferidas = \
-            rp.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_preferidas)
+            m_reg_pref.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_preferidas)
         self.matriz_cuadriculada_solo_regiones_preferidas = \
             np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
 
@@ -541,7 +395,7 @@ class Experimento:
                                        datos=self.matriz_cuadriculada_solo_regiones_preferidas.flatten())
 
         self.matriz_cuadriculada_solo_regiones_no_preferidas = \
-            rp.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
+            m_reg_pref.obtener_submatriz_indices_dados(matriz_cuadriculada, self.regiones_no_preferidas)
         self.matriz_cuadriculada_solo_regiones_no_preferidas = \
             np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
 
@@ -549,46 +403,13 @@ class Experimento:
                                        categoria="visitas_regiones_no_preferidas",
                                        datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
 
-    def obtener_indice_regiones_objeto(self):
-        lista_objetos_relevantes = [self.objeto_relevante_1,
-                                    self.objeto_relevante_2,
-                                    self.objeto_relevante_3,
-                                    self.objeto_relevante_4]
+    def calcula_arreglos_rutas_vectoriales(self, tamanio_vectorial, brinco_temporal, indice_consecuencia):
+        self.rutas_vectoriales.tamanio_vectorial = tamanio_vectorial
+        self.rutas_vectoriales.brinco_temporal = brinco_temporal
+        self.rutas_vectoriales.indice_consecuencia = indice_consecuencia
 
-        cantidad_filas = self.cantidad_filas
-        cantidad_columnas = self.cantidad_columnas
-
-        tamanio_horizontal = self.dimension_caja[0] / cantidad_columnas
-        tamanio_vertical = self.dimension_caja[1] / cantidad_filas
-
-        for objeto in lista_objetos_relevantes:
-
-            posicion_x = objeto[0]
-            posicion_y = objeto[1]
-
-            if posicion_x == self.dimension_caja[0]:
-                j = cantidad_columnas - 1
-            else:
-                j = posicion_x // tamanio_horizontal
-            if posicion_y == self.dimension_caja[1]:
-                i = cantidad_filas - 1
-            else:
-                i = posicion_y // tamanio_vertical
-
-            if self.indice_region_objeto_1 is None:
-                self.indice_region_objeto_1 = cantidad_columnas * i + j
-            elif self.indice_region_objeto_2 is None:
-                self.indice_region_objeto_2 = cantidad_columnas * i + j
-            elif self.indice_region_objeto_3 is None:
-                self.indice_region_objeto_3 = cantidad_columnas * i + j
-            elif self.indice_region_objeto_4 is None:
-                self.indice_region_objeto_4 = cantidad_columnas * i + j
-
-        print("Región de objeto 1: ", self.indice_region_objeto_1)
-        print("Región de objeto 2: ", self.indice_region_objeto_2)
-        print("Región de objeto 3: ", self.indice_region_objeto_3)
-        print("Región de objeto 4: ", self.indice_region_objeto_4)
-        print("-------------------------------------------------------------------")
+        self.rutas_vectoriales.obtener_posiciones_vectores()
+        self.rutas_vectoriales.obtener_direcciones_vectores()
 
     def genera_modulo_para_reducir_sesiones(self):
 
@@ -806,7 +627,7 @@ class Experimento:
 
         print(tabla_csv)
 
-        tabla_csv.to_csv(nombre, index=None)
+        tabla_csv.to_csv(nombre, index=False)
 
     def exporta_estadisticas(self, nombre):
         data = {'1': ['Max_Vel', 'Max_Accel', 'Total_Dist', 'Recurrence Matrix'],
@@ -825,7 +646,7 @@ class Experimento:
         datos_a_exportar = datos_a_exportar.append(data_para_matriz_tiempos)
         print("------------------------------------------------------------------------")
         print(datos_a_exportar)
-        pd.DataFrame(datos_a_exportar).to_csv(nombre, header=None, index=None)
+        pd.DataFrame(datos_a_exportar).to_csv(nombre, header=None, index=False)
 
     def exporta_estadisticas_2(self, nombre):
         data = {'1': ['Max_Vel',
@@ -842,11 +663,11 @@ class Experimento:
                       pd.DataFrame(self.matriz_cuadriculada, columns=None, index=None)
                       ]}
         data = pd.DataFrame(data)
-        data.to_csv(nombre, header=None, index=None)
+        data.to_csv(nombre, header=None, index=False)
 
     def exporta_matriz_tiempo_regiones(self, nombre):
         data = pd.DataFrame(self.matriz_cuadriculada, columns=None, index=None)
-        data.to_csv(nombre, header=None, index=None)
+        data.to_csv(nombre, header=None, index=False)
 
     def exporta_regiones_circulares(self, nombre):
         data = {'1': ['Objeto_1',
@@ -859,7 +680,7 @@ class Experimento:
                       self.cantidad_posiciones_volumen_4,
                       ]}
         data = pd.DataFrame(data)
-        data.to_csv(nombre, header=None, index=None)
+        data.to_csv(nombre, header=None, index=False)
 
     def graficar_figura(self, nombre_grafica, config_grafica):
         print("-----------------------------------------------------------")
@@ -909,10 +730,6 @@ class Experimento:
             brinco_temporal, tamanio_vectores, consecuencia_elegida = \
                 config_grafica.regresa_config_grafica_consecuencias()
 
-            print("Brinco temporal: ", brinco_temporal)
-            print("Tamanio vectores: ", tamanio_vectores)
-            print("Consecuencia elegida:", consecuencia_elegida)
-
             x_pos_antes_consecuencia = self.posiciones_x.tolist()
             y_pos_antes_consecuencia = self.posiciones_y.tolist()
 
@@ -927,8 +744,6 @@ class Experimento:
                                                                 int(consecuencia_elegida):
                                                                 int(brinco_temporal)]
 
-            print("Tamanios iguales : ", len(x_pos_antes_consecuencia) == len(y_pos_antes_consecuencia))
-
             x_pos_despues_consecuencia = x_pos_despues_consecuencia[int(consecuencia_elegida):
                                                                     int(consecuencia_elegida + tamanio_vectores):
                                                                     int(brinco_temporal)]
@@ -941,8 +756,8 @@ class Experimento:
             new_y_pos_antes = y_pos_antes_consecuencia.copy()
             new_y_pos_antes.append(self.posiciones_y[consecuencia_elegida])
 
-            x_direct_antes, y_direct_antes = fa.obtener_vectores_posicion_flechas(new_x_pos_antes,
-                                                                                  new_y_pos_antes)
+            x_direct_antes, y_direct_antes = m_rv.obtener_vectores_posicion_flechas(new_x_pos_antes,
+                                                                                    new_y_pos_antes)
 
             print("x_pos_antes_consecuencia: ", x_pos_antes_consecuencia)
             print("y_pos_antes_consecuencia: ", y_pos_antes_consecuencia)
@@ -950,8 +765,8 @@ class Experimento:
             print("x_direct_antes: ", x_direct_antes)
             print("y_direct_antes: ", y_direct_antes)
 
-            x_direct_despues, y_direct_despues = fa.obtener_vectores_posicion_flechas(x_pos_despues_consecuencia,
-                                                                                      y_pos_despues_consecuencia)
+            x_direct_despues, y_direct_despues = m_rv.obtener_vectores_posicion_flechas(x_pos_despues_consecuencia,
+                                                                                        y_pos_despues_consecuencia)
 
             print("-----------------------------------------------------------")
 
@@ -1114,31 +929,42 @@ class Experimento:
         #    plt.legend()
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada':
-            if self.matriz_recurrencia_region_cuadriculada is None:
-                self.calcula_regiones_cuadriculadas()
             plt.grid(False)
+            self.calcula_matrices_de_recurrencia()
+            print("Matriz de recurrencia región cuadriculada:", self.matriz_recurrencia_region_cuadriculada)
             plt.imshow(-1 * self.matriz_recurrencia_region_cuadriculada, origin='lower', cmap='gray',
                        interpolation='nearest', vmin=-1, vmax=0)
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_1':
 
+            matriz_recurrencia_objeto_1 = self.lista_matrices_recurrencia_regiones_importantes[0]
+
             plt.grid(False)
-            plt.imshow(-1 * self.matriz_recurrencia_objeto_1, origin='lower', cmap='gray',
+            plt.imshow(-1 * matriz_recurrencia_objeto_1, origin='lower', cmap='gray',
                        interpolation='nearest', vmin=-1, vmax=0)
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_2':
+
+            matriz_recurrencia_objeto_2 = self.lista_matrices_recurrencia_regiones_importantes[1]
+
             plt.grid(False)
-            plt.imshow(-1 * self.matriz_recurrencia_objeto_2, origin='lower', cmap='gray',
+            plt.imshow(-1 * matriz_recurrencia_objeto_2, origin='lower', cmap='gray',
                        interpolation='nearest')
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_3':
+
+            matriz_recurrencia_objeto_3 = self.lista_matrices_recurrencia_regiones_importantes[2]
+
             plt.grid(False)
-            plt.imshow(-1 * self.matriz_recurrencia_objeto_3, origin='lower', cmap='gray',
+            plt.imshow(-1 * matriz_recurrencia_objeto_3, origin='lower', cmap='gray',
                        interpolation='nearest')
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_4':
+
+            matriz_recurrencia_objeto_4 = self.lista_matrices_recurrencia_regiones_importantes[3]
+
             plt.grid(False)
-            plt.imshow(-1 * self.matriz_recurrencia_objeto_4, origin='lower', cmap='gray',
+            plt.imshow(-1 * matriz_recurrencia_objeto_4, origin='lower', cmap='gray',
                        interpolation='nearest')
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada_combinada':
@@ -1168,7 +994,8 @@ class Experimento:
 
             print("Entro a regresión lineal")
 
-            tipo_regresion_lineal, brinco_temporal, longitud_serie_tiempo = config_grafica.regresa_config_grafica_regresion_lineal()
+            tipo_regresion_lineal, brinco_temporal, longitud_serie_tiempo = \
+                config_grafica.regresa_config_grafica_regresion_lineal()
 
             print("Tipo regresion lineal: ", tipo_regresion_lineal)
             print("Brinco temporal: ", brinco_temporal)
@@ -1183,11 +1010,11 @@ class Experimento:
 
             print("Arreglo series tiempo: ", arreglo_series_tiempo)
 
-            indices_tiempo, series_tiempo = arl.generar_series_tiempo(lista_a_procesar=arreglo_series_tiempo,
+            indices_tiempo, series_tiempo = m_arl.generar_series_tiempo(lista_a_procesar=arreglo_series_tiempo,
                                                                       brinco_temporal=brinco_temporal,
                                                                       longitud_ventana_tiempo=longitud_serie_tiempo)
 
-            resultados = arl.generar_regresion_lineal_para_series_tiempo(indices_tiempo=indices_tiempo,
+            resultados =m_arl.generar_regresion_lineal_para_series_tiempo(indices_tiempo=indices_tiempo,
                                                                          series_tiempo=series_tiempo)
 
             for indice in range(0, len(indices_tiempo)):
@@ -1206,13 +1033,13 @@ class Experimento:
             print("rot_grafica_3d", rot_grafica_3d)
 
             self.cantidad_posiciones_volumenes, self.radios_volumenes = \
-                cilindros.calcula_alturas_volumenes_circulares_objetos_relevantes(posiciones_x=self.posiciones_x,
-                                                                                  posiciones_y=self.posiciones_y,
-                                                                                  lista_objetos_relevantes=
-                                                                                  self.lista_objetos_relevantes,
-                                                                                  tamanio=tamanio_volumenes,
-                                                                                  divisiones=div_volumenes,
-                                                                                  tipo=tipo_grafica_volumen)
+                m_ci.calcula_alturas_volumenes_circulares_objetos_relevantes(posiciones_x=self.posiciones_x,
+                                                                             posiciones_y=self.posiciones_y,
+                                                                             lista_objetos_relevantes=
+                                                                             self.lista_objetos_relevantes,
+                                                                             tamanio=tamanio_volumenes,
+                                                                             divisiones=div_volumenes,
+                                                                             tipo=tipo_grafica_volumen)
 
             if getattr(sys, 'frozen', False):
                 os.environ['BASEMAPDATA'] = os.path.join(os.path.dirname(sys.executable), 'mplot3d')
@@ -1443,13 +1270,13 @@ class Experimento:
             regiones_preferidas = config_grafica.regiones_preferidas_3d
             print("Regiones preferidas: ", regiones_preferidas)
             total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
-            regiones_no_preferidas = rp.obtener_complemento_de_sublista(lista=total_regiones,
-                                                                        sublista=regiones_preferidas)
+            regiones_no_preferidas = m_reg_pref.obtener_complemento_de_sublista(lista=total_regiones,
+                                                                                sublista=regiones_preferidas)
             print("Regiones no preferidas: ", regiones_no_preferidas)
 
             self.matriz_cuadriculada_solo_regiones_preferidas = \
-                rp.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
-                                                   regiones_preferidas)
+                m_reg_pref.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
+                                                                     regiones_preferidas)
             self.matriz_cuadriculada_solo_regiones_preferidas = \
                 np.flipud(self.matriz_cuadriculada_solo_regiones_preferidas)
 
@@ -1540,12 +1367,12 @@ class Experimento:
             regiones_preferidas = config_grafica.regiones_preferidas_3d
             print("Regiones preferidas: ", regiones_preferidas)
             total_regiones = list(range(0, self.cantidad_columnas * self.cantidad_filas))
-            regiones_no_preferidas = rp.obtener_complemento_de_sublista(lista=total_regiones,
+            regiones_no_preferidas = m_reg_pref.obtener_complemento_de_sublista(lista=total_regiones,
                                                                         sublista=regiones_preferidas)
             print("Regiones no preferidas: ", regiones_no_preferidas)
 
             self.matriz_cuadriculada_solo_regiones_no_preferidas = \
-                rp.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
+                m_reg_pref.obtener_submatriz_indices_dados(np.flipud(self.matriz_cuadriculada),
                                                    regiones_no_preferidas)
             self.matriz_cuadriculada_solo_regiones_no_preferidas = \
                 np.flipud(self.matriz_cuadriculada_solo_regiones_no_preferidas)
@@ -1631,5 +1458,3 @@ class Experimento:
             ax.view_init(azim=rot_grafica_3d)
 
         return fig
-
-
