@@ -27,9 +27,10 @@ class ConfigGrafica:
         self.brinco_temporal_consecuencias = 1
         self.tamanio_vectores_consecuencias = 1
 
-        self.tipo_arreglo_regresion_lineal = "Velocidad"
-        self.brinco_temporal_regresion_lineal = 2
-        self.longitud_serie_tiempo = 2
+        self.resultados_regresion_lineal = None
+        self.indices_tiempo = None
+        self.series_tiempo = None
+        self.pendientes_regresion_lineal = None
 
         self.regiones_preferidas_3d = [0]
 
@@ -51,7 +52,11 @@ class ConfigGrafica:
         return self.dist_max_figuras, self.total_figuras, self.tipo_figura, self.rot_grafica_3d
 
     def regresa_config_grafica_regresion_lineal(self):
-        return self.tipo_arreglo_regresion_lineal, self.brinco_temporal_regresion_lineal, self.longitud_serie_tiempo
+        return self.resultados_regresion_lineal,\
+               self.indices_tiempo,\
+               self.series_tiempo
 
     def regresa_config_grafica_consecuencias(self):
-        return self.brinco_temporal_consecuencias, self.tamanio_vectores_consecuencias, self.consecuencia_elegida
+        return self.brinco_temporal_consecuencias,\
+               self.tamanio_vectores_consecuencias,\
+               self.consecuencia_elegida
