@@ -1,8 +1,5 @@
 from motus.experimento import Experimento
-import motus.fisica_estadistica.entropia_divergencia as ed
-import numpy as np
-from scipy.stats import entropy
-import matplotlib.pyplot as plt
+import motus.entropia_divergencia.entropia_divergencia as ed
 from matplotlib.figure import Figure
 
 
